@@ -57,6 +57,7 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <glyphstr.h>
 #include <picturestr.h>
 #include <gcstruct.h>
+#include <xvdix.h>
 
 #include <pciaccess.h>
 
@@ -256,6 +257,11 @@ struct sna {
 		void *flip_pending;
 	} dri;
 
+	struct sna_xv {
+		XvAdaptorPtr adaptors;
+		int num_adaptors;
+	} xv;
+
 	unsigned int tiling;
 #define SNA_TILING_FB		0x1
 #define SNA_TILING_2D		0x2
