@@ -631,6 +631,10 @@ static Bool sna_pre_init(ScrnInfoPtr scrn, int flags)
 	xf86DrvMsg(scrn->scrnIndex, X_CONFIG, "Forcing per-crtc-pixmaps? %s\n",
 		   sna->flags & SNA_FORCE_SHADOW ? "yes" : "no");
 
+	if (sna->tiling != SNA_TILING_ALL)
+		xf86DrvMsg(scrn->scrnIndex, X_WARNING,
+			   "Tiling disabled, expect poor performance and increased power consumption.\n");
+
 	if (!sna_mode_pre_init(scrn, sna)) {
 		PreInitCleanup(scrn);
 		return FALSE;
@@ -916,7 +920,7 @@ sna_register_all_privates(void)
 		return FALSE;
 
 	if (!dixRegisterPrivateKey(&sna_window_key, PRIVATE_WINDOW,
-				   2*sizeof(void *)))
+				   3*sizeof(void *)))
 		return FALSE;
 #else
 	if (!dixRequestPrivate(&sna_pixmap_key, 3*sizeof(void *)))
@@ -928,7 +932,7 @@ sna_register_all_privates(void)
 	if (!dixRequestPrivate(&sna_glyph_key, sizeof(struct sna_glyph)))
 		return FALSE;
 
-	if (!dixRequestPrivate(&sna_window_key, 2*sizeof(void *)))
+	if (!dixRequestPrivate(&sna_window_key, 3*sizeof(void *)))
 		return FALSE;
 #endif
 
