@@ -427,13 +427,14 @@ move_to_gpu(PixmapPtr pixmap, const BoxRec *box, bool blt)
 		return NULL;
 	}
 
+	if (priv->shm)
+		blt = true;
+
 	if (priv->gpu_bo) {
 		if (priv->cpu_damage &&
 		    sna_damage_contains_box(priv->cpu_damage,
-					    box) != PIXMAN_REGION_OUT) {
-			if (!sna_pixmap_move_to_gpu(pixmap, MOVE_READ))
-				return NULL;
-		}
+					    box) != PIXMAN_REGION_OUT)
+			goto upload;
 
 		return priv->gpu_bo;
 	}
@@ -450,9 +451,6 @@ move_to_gpu(PixmapPtr pixmap, const BoxRec *box, bool blt)
 		return NULL;
 	}
 
-	if (priv->shm)
-		blt = true;
-
 	if (DBG_FORCE_UPLOAD < 0) {
 		if (!sna_pixmap_force_to_gpu(pixmap,
 					     blt ? MOVE_READ : MOVE_SOURCE_HINT | MOVE_READ))
@@ -493,6 +491,7 @@ move_to_gpu(PixmapPtr pixmap, const BoxRec *box, bool blt)
 	if (!migrate)
 		return NULL;
 
+upload:
 	if (blt) {
 		if (!sna_pixmap_move_area_to_gpu(pixmap, box,
 						 __MOVE_FORCE | MOVE_READ))
@@ -1734,7 +1733,7 @@ sna_render_picture_convert(struct sna *sna,
 	     pixmap->drawable.width,
 	     pixmap->drawable.height));
 
-	if (w == 0 || h == 0) {
+	if (w <= 0 || h <= 0) {
 		DBG(("%s: sample extents lie outside of source, using clear\n",
 		     __FUNCTION__));
 		return 0;
